Module python_parser::ast [−][src]
enums and structures that store the syntax tree outputed by the parser.
Structs
| Classdef |
A class definition, including its decorators. |
| Decorator |
A function or class decorator. |
| Funcdef |
A function definition, including its decorators. |
| PyString |
A Python string. See the doc of the crate for the boring speech about encoding stuff. |
| Try |
A try block. |
| TypedArgsList |
The list of parameters of a function definition. |
| UntypedArgsList |
The list of parameters of a lambda definition. |
Enums
| Argument |
An argument to a function call |
| AugAssignOp |
|
| Bop |
Binary operators. |
| CompoundStatement |
Statements with blocks. |
| ComprehensionChunk |
One of the |
| DictItem |
|
| Expression |
The big thing: a Python expression. |
| Import |
An import statement. |
| SetItem |
|
| StarParams |
Represents whether a function signature has |
| Statement |
A Python statement. |
| Subscript |
The |
| Uop |
Unary operators. |
Type Definitions
| IntegerType | |
| Name | |
| PyStringCodePoint | |
| PyStringContent |